Learn R Programming

simstudy (version 0.2.0)

distributions: Distributions for Data Definitions

Description

This help file describes the distributions used for data creation in simstudy.

Arguments

formula

Desired mean as a Number or an R expression for mean as a String. Variables defined via defData() and variables within the parent environment (prefixed with ..) can be used within the formula. Functions from the parent environment can be used without a prefix.

variance

Number. Default is 0.

link

String identifying the link function to be used. Default is identity.

Mixture

The mixture distribution makes it possible to mix to previously defined distributions/variables. Each variable that should be part of the new distribution x_1,...,X_n is assigned a probability p_1,...,p_n. For more information see rdatagen.net.

Details

For details about the statistical distributions please see stats::distributions, any non-statistical distributions will be explained below. Required variables and expected pattern for each distribution can be found in this table:

name formula format variance link
beta mean String or Number dispersion value identity or logit
binary probability for 1 String or Number NA identity or logit
binomial probability of success String or Number number of trials identity or logit
categorical probabilities p_1;p_2;..;p_n NA NA
exponential mean (lambda) String or Number NA identity or log
gamma mean String or Number dispersion value identity or log
mixture formula x_1 |p_1 + x_2|p_2 ... x_n| p_n NA NA
negBinomial mean String or Number dispersion value identity or log
nonrandom formula String or Number NA NA
normal mean String or Number variance NA
noZeroPoisson mean String or Number NA identity or log
poisson mean String or Number NA identity or log
uniform range from;to NA NA
uniformInt range from;to NA NA

Examples

Run this code
# NOT RUN {
ext_var <- 2.9
def <- defData(varname = "external", formula = "3 + log(..ext_var)", variance = .5)
def
genData(5, def)
# }

Run the code above in your browser using DataLab