number of rows and columns (i.e. number of variables) for correlation matrix
cors
vector of correlations.
Value
correlation matrix of size nvars x nvars
Details
If the vector cors is not specified, a random correlation matrix is generated with no assumptions.
If the vector is provided, it should be interpreted as the lower triangle of the correlation
matrix, and is specified by reading down the columns. For example, if CM is the correlation matrix and
nvars = 3, then CM[2,1] = cors[1], CM[3,1] = cors[2], and CM[3,2] = cors[3].